import 'package:meta/meta.dart';

import 'client/client.dart';

/// Initialize the `lumberdartClient` internally
LumberdartClient _lumberdartClient = SimpleClient();

/// Get the instance of the given [LumberdartClient]
LumberdartClient get lumberdartClient => _lumberdartClient;

/// As it name says, it puts Lumberdart to work by setting up its
/// [LumberdartClient]. With this library you could use [SimpleClient]
/// to start logging on stoudt, but the full power of Lumberdart can
/// be achieved when you use a custom [LumberdartClient] that fits
/// your logging requirements.
putLumberdartToWork({@required LumberdartClient withClient}) {
  assert(withClient != null);
  _lumberdartClient = withClient;
}

/// It calls the `logMessage` method of the given [LumberdartClient]
/// passed to `putLumberdartToWork`, and returns the given `message`.
String logMessage(String message, [Map<String, dynamic> extras]) {
  _lumberdartClient.logMessage(message, extras);
  return message;
}

/// It calls the `logWarning` method of the given [LumberdartClient]
/// passed to `putLumberdartToWork`, and returns the given `message`.
String logWarning(String message, [Map<String, dynamic> extras]) {
  _lumberdartClient.logWarning(message, extras);
  return message;
}

/// It calls the `logFatal` method of the given [LumberdartClient]
/// passed to `putLumberdartToWork`, and returns the given `message`.
String logFatal(String message, [Map<String, dynamic> extras]) {
  _lumberdartClient.logFatal(message, extras);
  return message;
}

/// It calls the `logError` method of the given [LumberdartClient]
/// passed to `putLumberdartToWork`, and returns the given `exception`.
dynamic logError(dynamic exception, [dynamic stacktrace]) {
  _lumberdartClient.logError(exception, stacktrace);
  return exception;
}
